/**
 * TableOfContents.js
 * ------------------
 * This file defines the createTocEntry function and a test
 * framework to demonstrate that it's implemented correctly.
 */

"use strict";

/* Constants */
const TOC_LINE_LENGTH = 60;

/**
 * Function: createTocEntry
 * ------------------------
 * Returns a string of length TOC_LINE_LENGTH that's prefixed by
 * title, suffixed by the page number, and includes a leader in
 * between the title and page number according to the rules laid
 * out in the problem statement.
 */
function createTocEntry(title, page) {
	if (title.length % 2 === 0) title += " ";
	let entry = title + " ";
	page = " " + page; // convert page from number to string with padding
	let gap = TOC_LINE_LENGTH - entry.length - page.length;
	let leader = "";
	for (let i = 0; i < gap; i++) {
		let ch = i % 2 === 0 ? "." : " ";
		leader += ch;
	}
	return entry + leader + page;
}

/* Test Framework Constants */
const CS106AJ_READER_CHAPTERS = [
	null,													// there is no Chapter 0
	{title: "A Gentle Introduction", page: 1},				// Chapter 1
	{title: "Introducing JavaScript", page: 39},			// Chapter 2
	{title: "Running Programs in the Browser", page: 63},	// and so forth
	{title: "Control Statements", page: 103},
	{title: "Functions", page: 143},
	{title: "Writing Interactive Programs ", page: 181},
	{title: "String", page: 219},
	{title: "Arrays", page: 255},
	{title: "Objects", page: 295}
];
const NUM_CHAPTERS = CS106AJ_READER_CHAPTERS.length - 1;

/**
 * Function: TableOfContents
 * -------------------------
 * Exercises our createTocEntry function above by listing
 * out the entire table of contents for our CS106AJ reader.
 */
function TableOfContents() {
	for (let chapter = 1; chapter <= NUM_CHAPTERS; chapter++) {
		let title = chapter + ". " + CS106AJ_READER_CHAPTERS[chapter].title;
		let page = CS106AJ_READER_CHAPTERS[chapter].page;
		let entry = createTocEntry(title, page);
		console.log(entry);
	}
}
