/**
 * File: Exchanges.js
 * ------------------
 * Exports the readLetters function, which knows
 * how to parse the embedded XML of the index.html, and
 * construct and return an array of objects, each of which
 * represents a correspondence between its author and its
 * recipient.
 */

"use strict";

/**
 * Function: readLetters
 * ---------------------
 * Parses the XML content of the surrounding HTML file and returns
 * an array of aggregates, where each aggregate stores information
 * about a single exchange between two people, as specified in the
 * problem statement.
 */
function readLetters() {
	let exchangesXML = document.getElementById("ExchangesData");
	let letterElements = exchangesXML.getElementsByTagName("letter");
	let letters = [];
	for (let i = 0; i < letterElements.length; i++) {
		letters.push(letterElementToAggregate(letterElements[i]));
	}
	return letters;
}

/**
 * Function: letterElementToAggregate
 * ----------------------------------
 * Parses the XML rooted at the provided letter element
 * and returns an aggregate housing precisely the same
 * information, as outlined in the problem statement.
 */
function letterElementToAggregate(element) {
	let lines = element.innerHTML.split("\n");
	let body = [];

	for (let i = 0; i < lines.length; i++) {
		let line = lines[i].trim();
		if (line.length > 0) body.push(line);
	}

	let letter = {
		to: element.getAttribute("to"),
		from: element.getAttribute("from"),
		date: element.getAttribute("date"),
		body: body
	};

	return letter;
}

/**
 * Function: TestReadLetters
 * -------------------------
 * Simple function in place to demonstrate that readLetters
 * works properly.
 */
function TestReadLetters() {
	let letters = readLetters();
	for (let i = 0; i < letters.length; i++) {
		console.log("  Written By: " + letters[i].from);
		console.log("     Sent To: " + letters[i].to);
		console.log("        Date: " + letters[i].date);
		console.log("              ------------");
		for (let j = 0; j < letters[i].body.length; j++) {
			console.log("              " + letters[i].body[j]);
		}
		console.log("              ------------");
	}
}
